@@ -31,16 +31,17 @@
 
 #include <KLocalizedString>
 #include <KMessageBox>
-#include <KPluginLoader>
 
 #include <QGuiApplication>
+#include <QJsonArray>
+#include <QPluginLoader>
 
 
 /** Defines the used plugin version number.
  *
  *  This must match the desktop files.
  */
-const int Plugins::PluginManager::s_pluginFrameworkVersion = 77;
+const int Plugins::PluginManager::s_pluginFrameworkVersion = 78;
 Plugins::PluginManager* Plugins::PluginManager::s_instance = nullptr;
 
 Plugins::PluginManager*
@@ -63,7 +64,7 @@ Plugins::PluginManager::PluginManager( QObject *parent )
     : QObject( parent )
 {
     DEBUG_BLOCK
-    setObjectName( "PluginManager" );
+    setObjectName( QStringLiteral("PluginManager") );
     s_instance = this;
 
     PERF_LOG( "Initialising Plugin Manager" )
@@ -90,16 +91,14 @@ Plugins::PluginManager::init()
     checkPluginEnabledStates();
 }
 
-KPluginInfo::List
+QVector<KPluginMetaData>
 Plugins::PluginManager::plugins( Type type ) const
 {
-    KPluginInfo::List infos;
+    QVector<KPluginMetaData> infos;
 
     for( const auto &pluginInfo : m_pluginsByType.value( type ) )
     {
-        auto info = KPluginInfo( pluginInfo );
-        info.setConfig( Amarok::config( "Plugins" ) );
-        infos << info;
+        infos << pluginInfo;
     }
 
     return infos;
@@ -230,8 +229,8 @@ Plugins::PluginManager::isPluginEnabled( const KPluginMetaData &plugin ) const
     // mysql storage and collection are vital. They need to be loaded always
 
     auto raw = plugin.rawData();
-    int version = raw.value( "X-KDE-Amarok-framework-version" ).toInt();
-    int rank = raw.value( "X-KDE-Amarok-rank" ).toInt();
+    int version = raw.value( QStringLiteral("X-KDE-Amarok-framework-version") ).toInt();
+    int rank = raw.value( QStringLiteral("X-KDE-Amarok-rank") ).toInt();
 
     if( version != s_pluginFrameworkVersion )
     {
@@ -250,18 +249,14 @@ Plugins::PluginManager::isPluginEnabled( const KPluginMetaData &plugin ) const
 
     if( !vital.isUndefined())
     {
-        if( vital.toBool() || vital.toString().toLower() == "true" )
+        if( vital.toBool() || vital.toString().toLower() == QStringLiteral("true") )
         {
             debug() << "Plugin" << plugin.pluginId() << "is vital";
             return true;
         }
     }
 
-    KPluginInfo info = KPluginInfo( plugin );
-    info.setConfig( Amarok::config( "Plugins" ) );
-    info.load();
-
-    return info.isPluginEnabled();
+    return plugin.isEnabled( Amarok::config( QStringLiteral("Plugins") ) );
 }
 
 
@@ -285,7 +280,7 @@ Plugins::PluginManager::createFactory( const KPluginMetaData &pluginInfo )
 
     if( !pluginFactory )
     {
-        warning() << QString( "Failed to get factory '%1' from QPluginLoader: %2" )
+        warning() << QStringLiteral( "Failed to get factory '%1' from QPluginLoader: %2" )
                      .arg( name, loader.errorString() );
         return QSharedPointer<Plugins::PluginFactory>();
     }
@@ -300,8 +295,17 @@ Plugins::PluginManager::findPlugins()
 {
     QVector<KPluginMetaData> plugins;
     for( const auto &location : QCoreApplication::libraryPaths() )
-        plugins << KPluginLoader::findPlugins( location, [] ( const KPluginMetaData &metadata )
-            { return metadata.serviceTypes().contains( QStringLiteral( "Amarok/Plugin" ) ); } );
+        plugins << KPluginMetaData::findPlugins( location, [] ( const KPluginMetaData &metadata )
+            { // deprecated/removed serviceTypes() functionality just replicated here, TODO convert the metadata to something more modern
+                if( !metadata.rawData().contains( QStringLiteral( "KPlugin" ) ) )
+                    return false;
+                auto obj = metadata.rawData().value( QStringLiteral( "KPlugin" ) ).toObject();
+                if( obj == QJsonObject() )
+                    return false;
+                if( obj.value( QStringLiteral( "ServiceTypes" ) ).toArray() == QJsonArray() )
+                    return false;
+                return obj.value( QStringLiteral( "ServiceTypes" ) ).toArray().contains( QStringLiteral("Amarok/Plugin" ) );
+            } );
 
     for( const auto &plugin : plugins )
     {
