@@ -27,7 +27,6 @@
 #include "core/support/Amarok.h"
 #include "core/support/Debug.h"
 
-#include <QHashIterator>
 #include <QRegularExpression>
 #include <QStandardPaths>
 #include <QUrlQuery>
@@ -42,7 +41,7 @@ WikipediaEngine::WikipediaEngine( QObject* parent )
     , useMobileVersion( false )
     , m_pauseState( false )
 {
-    preferredLangs = Amarok::config("Wikipedia Applet").readEntry( "PreferredLang", QStringList() << "en" );
+    preferredLangs = Amarok::config(QStringLiteral("Wikipedia Applet")).readEntry( "PreferredLang", QStringList() << QStringLiteral("en") );
 
     EngineController *engine = The::engineController();
 
@@ -80,7 +79,7 @@ WikipediaEngine::_wikiResult( const QUrl &url, const QByteArray &result, const N
     }
 
     debug() << "Received page from wikipedia:" << url;
-    QString wiki( result );
+    QString wiki = QString::fromUtf8( result );
 
     // FIXME: For now we test if we got an article or not with a test on this string "wgArticleId=0"
     // This is bad
@@ -231,7 +230,7 @@ WikipediaEngine::_parseLangLinksResult( const QUrl &url, const QByteArray &data,
     }
     else
     {
-        QRegExp regex( QLatin1Char('^') + hostLang + QLatin1String(".*$") );
+        QRegularExpression regex( QLatin1Char('^') + hostLang + QLatin1String(".*$") );
         int index = preferredLangs.indexOf( regex );
         if( (index != -1) && (index < preferredLangs.count() - 1) )
         {
@@ -242,7 +241,7 @@ WikipediaEngine::_parseLangLinksResult( const QUrl &url, const QByteArray &data,
         }
         else
         {
-            QStringList refinePossibleLangs = preferredLangs.filter( QRegExp("^(en|fr|de|pl).*$") );
+            QStringList refinePossibleLangs = preferredLangs.filter( QRegularExpression(QStringLiteral("^(en|fr|de|pl).*$")) );
             if( refinePossibleLangs.isEmpty() )
             {
                 clear();
@@ -297,7 +296,7 @@ WikipediaEngine::_parseListingResult( const QUrl &url,
 
     if( titles.isEmpty() )
     {
-        QStringList refinePossibleLangs = preferredLangs.filter( QRegExp("^(en|fr|de|pl).*$") );
+        QStringList refinePossibleLangs = preferredLangs.filter( QRegularExpression(QStringLiteral("^(en|fr|de|pl).*$")) );
         int index = refinePossibleLangs.indexOf( hostLang );
         if( (index != -1) && (index < refinePossibleLangs.count() - 1) )
             fetchListing( title, refinePossibleLangs.value( index + 1 ).split( QLatin1Char(':') ).back() );
@@ -314,22 +313,22 @@ WikipediaEngine::_parseListingResult( const QUrl &url,
     {
     default:
     case Artist:
-        pattern = i18nc("Search pattern for an artist or band", ".*\\(.*(artist|band).*\\))").toLatin1();
+        pattern = i18nc("Search pattern for an artist or band", ".*\\(.*(artist|band).*\\)");
         break;
     case Composer:
-            pattern = i18nc("Search pattern for a composer", ".*\\(.*(composer|musician).*\\))").toLatin1();
+            pattern = i18nc("Search pattern for a composer", ".*\\(.*(composer|musician).*\\)");
         break;
     case Album:
-            pattern = i18nc("Search pattern for an album", ".*\\(.*(album|score|soundtrack).*\\)").toLatin1();
+            pattern = i18nc("Search pattern for an album", ".*\\(.*(album|score|soundtrack).*\\)");
         break;
 
     case Track:
-            pattern = i18nc("Search pattern for a song", ".*\\(.*(song|track).*\\)").toLatin1();
+            pattern = i18nc("Search pattern for a song", ".*\\(.*(song|track).*\\)");
         break;
     }
 
     pattern.prepend( title );
-    int patternIndex = titles.indexOf( QRegExp(pattern, Qt::CaseInsensitive) );
+    int patternIndex = titles.indexOf( QRegularExpression(pattern, QRegularExpression::CaseInsensitiveOption) );
     const QString result = ( patternIndex != -1 ) ? titles.at( patternIndex ) : titles.first();
     fetchWikiUrl( result, hostLang ); // end of the line
 }
@@ -399,22 +398,22 @@ WikipediaEngine::_paletteChanged( const QPalette &palette )
     DEBUG_BLOCK
 
     // read css, replace color placeholders, write to file, load into page
-    QFile file( QStandardPaths::locate( QStandardPaths::GenericDataLocation, "amarok/data/WikipediaCustomStyle.css" ) );
+    QFile file( QStandardPaths::locate( QStandardPaths::GenericDataLocation, QStringLiteral("amarok/data/WikipediaCustomStyle.css") ) );
     if( file.open(QIODevice::ReadOnly | QIODevice::Text) )
     {
-        QString contents = QString( file.readAll() );
-        contents.replace( "/*{text_color}*/", palette.text().color().name() );
-        contents.replace( "/*{link_color}*/", palette.link().color().name() );
-        contents.replace( "/*{link_hover_color}*/", palette.linkVisited().color().name() );
-        contents.replace( "/*{background_color}*/", palette.base().color().name() );
+        QString contents = QLatin1String( file.readAll() );
+        contents.replace( QStringLiteral("/*{text_color}*/"), palette.text().color().name() );
+        contents.replace( QStringLiteral("/*{link_color}*/"), palette.link().color().name() );
+        contents.replace( QStringLiteral("/*{link_hover_color}*/"), palette.linkVisited().color().name() );
+        contents.replace( QStringLiteral("/*{background_color}*/"), palette.base().color().name() );
 
         const QString abg = palette.window().color().name();
-        contents.replace( "/*{shaded_text_background_color}*/", abg );
-        contents.replace( "/*{table_background_color}*/", abg );
-        contents.replace( "/*{headings_background_color}*/", abg );
+        contents.replace( QStringLiteral("/*{shaded_text_background_color}*/"), abg );
+        contents.replace( QStringLiteral("/*{table_background_color}*/"), abg );
+        contents.replace( QStringLiteral("/*{headings_background_color}*/"), abg );
 
         const QString atbg = palette.alternateBase().color().name();
-        contents.replace( "/*{alternate_table_background_color}*/", atbg );
+        contents.replace( QStringLiteral("/*{alternate_table_background_color}*/"), atbg );
 
         if( m_css == contents )
             return;
@@ -432,7 +431,7 @@ void
 WikipediaEngine::fetchWikiUrl( const QString &title, const QString &urlPrefix )
 {
     QUrl pageUrl;
-    QString host( ".wikipedia.org" );
+    QString host( QStringLiteral(".wikipedia.org") );
     pageUrl.setScheme( QLatin1String( "https" ) );
 
 //     if( useMobileVersion )
@@ -625,10 +624,9 @@ WikipediaEngine::wikiParse( QString &wiki )
     int langSectionIndex = 0;
     if( (langSectionIndex = wiki.indexOf( QLatin1String("<div id=\"p-lang\" class=\"portlet\">") )) != -1 )
     {
-        QStringRef sref = wiki.midRef( langSectionIndex );
-        sref = wiki.midRef( sref.position(), wiki.indexOf( QLatin1String("<ul>"), sref.position() ) - sref.position() );
-        sref = wiki.midRef( sref.position(), wiki.indexOf( QLatin1String("</dev>"), sref.position() ) - sref.position() );
-        wikiLanguagesSection = sref.toString();
+        int ulpos = wiki.indexOf( QLatin1String("<ul>"), langSectionIndex );
+        int devpos = wiki.indexOf( QLatin1String("</dev>"), ulpos );
+        wikiLanguagesSection = wiki.mid( langSectionIndex, devpos - langSectionIndex );
         QXmlStreamReader xml( wikiLanguagesSection );
         while( !xml.atEnd() && !xml.hasError() )
         {
@@ -653,23 +651,23 @@ WikipediaEngine::wikiParse( QString &wiki )
     int copyrightIndex = wiki.indexOf( copyrightMark );
     if( copyrightIndex != -1 )
     {
-        QStringRef sref = wiki.midRef( copyrightIndex + copyrightMark.length() );
-        sref = wiki.midRef( sref.position(), wiki.indexOf( QLatin1String("</li>"), sref.position() ) - sref.position() );
-        copyright = sref.toString();
+        const uint pos = copyrightIndex + copyrightMark.length();
+        copyright = wiki.mid( pos, wiki.indexOf( QLatin1String("</li>"), pos ) - pos );
         copyright.remove( QLatin1String("<br />") );
         //only one br at the beginning
         copyright.prepend( QLatin1String("<br />") );
     }
 
-    const int titleIndex = wiki.indexOf( QRegExp( QLatin1String("<title>[^<]*</title>") ) ) + 7;
+    const int titleIndex = wiki.indexOf( QRegularExpression( QLatin1String("<title>[^<]*</title>") ) ) + 7;
     const int bsTitleIndex = wiki.indexOf( QLatin1String("</title>"), titleIndex ) - titleIndex;
     const QString title = wiki.mid( titleIndex, bsTitleIndex );
 
     // Ok lets remove the top and bottom parts of the page
-    QStringRef wikiRef;
-    wikiRef = wiki.midRef( wiki.indexOf( QLatin1String("<!-- start content -->") ) );
-    wikiRef = wiki.midRef( wikiRef.position(), wiki.indexOf( QLatin1String("<div class=\"printfooter\">"), wikiRef.position() ) - wikiRef.position() );
-    wiki = wikiRef.toString();
+    QStringView wikiRef;
+    const int contentStart = wiki.indexOf( QLatin1String("<!-- start content -->") );
+    const int contentEnd = wiki.indexOf( QLatin1String("<div class=\"printfooter\">"), contentStart );
+
+    wiki = wiki.mid( contentStart, contentEnd - contentStart );
 
     auto removeTag = [&wiki] ( const QString& tagStart, const QString& tagEnd )
     {
@@ -679,29 +677,29 @@ WikipediaEngine::wikiParse( QString &wiki )
         while( ( matchIndex = tagMatcher.indexIn( wiki, matchIndex ) ) != -1 )
         {
             const int nToTagEnd = wiki.indexOf( tagEnd, matchIndex ) - matchIndex;
-            const QStringRef tagRef = wiki.midRef( matchIndex, nToTagEnd + tagEndSize );
+            const QStringView tagRef = wiki.midRef( matchIndex, nToTagEnd + tagEndSize );
             wiki.remove( tagRef.toString() );
         }
     };
 
-    QString header = QString( "<html>\n<head>\n<title>%1</title>\n</head>\n<body>\n" ).arg( title );
+    QString header = QStringLiteral( "<html>\n<head>\n<title>%1</title>\n</head>\n<body>\n" ).arg( title );
 
     // add own stylesheet
     if( !m_css.isEmpty() )
     {
-        removeTag( "<link rel=\"stylesheet\"", "/>" );
+        removeTag( QStringLiteral("<link rel=\"stylesheet\""), QStringLiteral("/>") );
         int index = header.indexOf( QStringLiteral( "</head>" ) );
-        header.insert( index, QString( "\n<style>\n%1\n</style>\n" ).arg( m_css ) );
+        header.insert( index, QStringLiteral( "\n<style>\n%1\n</style>\n" ).arg( m_css ) );
     }
 
     wiki.prepend( header );
 
     // lets remove the warning box
-    removeTag( "<table class=\"metadata plainlinks ambox", "</table>" );
+    removeTag( QStringLiteral("<table class=\"metadata plainlinks ambox"), QStringLiteral("</table>") );
     // remove protection policy (we don't do edits)
-    removeTag( "<div><a href=\"/wiki/Wikipedia:Protection_policy", "</a></div>" );
+    removeTag( QStringLiteral("<div><a href=\"/wiki/Wikipedia:Protection_policy"), QStringLiteral("</a></div>") );
     // lets also remove the "lock" image
-    removeTag( "<div class=\"metadata topicon\" ", "</a></div>" );
+    removeTag( QStringLiteral("<div class=\"metadata topicon\" "), QStringLiteral("</a></div>") );
     // remove <audio> tags (can lead to crashes in QtWebKit)
 //     removeTag( "<audio", "</audio>" );
 
@@ -709,32 +707,32 @@ WikipediaEngine::wikiParse( QString &wiki )
     wiki = QLatin1String("<div id=\"bodyContent\"") + wiki;
     wiki += copyright;
     wiki.append( QLatin1String("</div>") );
-    wiki.remove( QRegExp( QLatin1String("<h3 id=\"siteSub\">[^<]*</h3>") ) );
+    wiki.remove( QRegularExpression( QLatin1String("<h3 id=\"siteSub\">[^<]*</h3>") ) );
 
-    wiki.remove( QRegExp( QLatin1String("<span class=\"editsection\"[^>]*>[^<]*<[^>]*>[^<]*<[^>]*>[^<]*</span>") ) );
-    wiki.remove( QRegExp( QLatin1String("<p><span[^>]*><[^\"]*\"#_skip_noteTA\">[^<]*<[^<]*</span></p>") ) );
+    wiki.remove( QRegularExpression( QLatin1String("<span class=\"editsection\"[^>]*>[^<]*<[^>]*>[^<]*<[^>]*>[^<]*</span>") ) );
+    wiki.remove( QRegularExpression( QLatin1String("<p><span[^>]*><[^\"]*\"#_skip_noteTA\">[^<]*<[^<]*</span></p>") ) );
 
-    wiki.replace( QRegExp( QLatin1String("<a href=\"[^\"]*\" class=\"new\"[^>]*>([^<]*)</a>") ), QLatin1String("\\1") );
+    wiki.replace( QRegularExpression( QLatin1String("<a href=\"[^\"]*\" class=\"new\"[^>]*>([^<]*)</a>") ), QLatin1String("\\1") );
 
     // Remove anything inside of a class called urlexpansion, as it's pointless for us
-    wiki.remove( QRegExp( QLatin1String("<span class= *'urlexpansion'>[^(]*[(][^)]*[)]</span>") ) );
+    wiki.remove( QRegularExpression( QLatin1String("<span class= *'urlexpansion'>[^(]*[(][^)]*[)]</span>") ) );
+
+    // Remove hidden table rows as well, greedy behaviour wouldn't be any good!
+    QRegularExpression hidden( QLatin1String("<tr *class= *[\"\']hiddenStructure[\"\']>.*</tr>"), QRegularExpression::CaseInsensitiveOption | QRegularExpression::InvertedGreedinessOption );
 
-    // Remove hidden table rows as well
-    QRegExp hidden( QLatin1String("<tr *class= *[\"\']hiddenStructure[\"\']>.*</tr>"), Qt::CaseInsensitive );
-    hidden.setMinimal( true ); //greedy behaviour wouldn't be any good!
     wiki.remove( hidden );
 
     // we want to keep our own style (we need to modify the stylesheet a bit to handle things nicely)
-    wiki.remove( QRegExp( QLatin1String("style= *\"[^\"]*\"") ) );
+    wiki.remove( QRegularExpression( QLatin1String("style= *\"[^\"]*\"") ) );
     // We need to leave the classes behind, otherwise styling it ourselves gets really nasty and tedious and roughly impossible to do in a sane manner
-    //wiki.replace( QRegExp( "class= *\"[^\"]*\"" ), QString() );
+    //wiki.replace( QRegularExpression( "class= *\"[^\"]*\"" ), QString() );
     // let's remove the form elements, we don't want them.
-    wiki.remove( QRegExp( QLatin1String("<input[^>]*>") ) );
-    wiki.remove( QRegExp( QLatin1String("<select[^>]*>") ) );
+    wiki.remove( QRegularExpression( QLatin1String("<input[^>]*>") ) );
+    wiki.remove( QRegularExpression( QLatin1String("<select[^>]*>") ) );
     wiki.remove( QLatin1String("</select>\n")  );
-    wiki.remove( QRegExp( QLatin1String("<option[^>]*>") ) );
+    wiki.remove( QRegularExpression( QLatin1String("<option[^>]*>") ) );
     wiki.remove( QLatin1String("</option>\n")  );
-    wiki.remove( QRegExp( QLatin1String("<textarea[^>]*>") ) );
+    wiki.remove( QRegularExpression( QLatin1String("<textarea[^>]*>") ) );
     wiki.remove( QLatin1String("</textarea>") );
 
     // wiki.append( createLanguageComboBox(langMap) ); // BUG:259075
@@ -884,18 +882,18 @@ WikipediaEngine::setLanguage(const QString& language)
 void
 WikipediaEngine::setUrl(const QUrl& url)
 {
-    if( !url.host().endsWith( ".wikipedia.org" ) )
+    if( !url.host().endsWith( QStringLiteral(".wikipedia.org") ) )
     {
-        setMessage( QString( "<a href=\"%1\">").arg( url.toString() ) +
+        setMessage( QStringLiteral( "<a href=\"%1\">").arg( url.toString() ) +
             i18nc( "A message (link) shown for clicked non-Wikipedia links in Wikipedia applet. %1 is the url of the link",
-                   "Click to open %1 in a web browser", url.toString() ) + "</a>" );
+                   "Click to open %1 in a web browser", url.toString() ) + QStringLiteral("</a>") );
         return;
     }
     QUrl monobookUrl = url;
     monobookUrl.setPath( QLatin1String("/w/index.php") );
 
     QUrlQuery query;
-    query.addQueryItem( QLatin1String("title"), url.path().mid( url.path().lastIndexOf("/") + 1 ) );
+    query.addQueryItem( QLatin1String("title"), url.path().mid( url.path().lastIndexOf(QStringLiteral("/")) + 1 ) );
     query.addQueryItem( QLatin1String("redirects"), QString::number(1) );
     query.addQueryItem( QLatin1String("useskin"), QLatin1String("monobook") );
     monobookUrl.setQuery( query );
