@@ -37,24 +37,24 @@ class MetaStream::Track::Private : public QObject
         Private( Track *t )
             : trackNumber( 0 )
             , length( 0 )
-            , rating( 0 )
-            , score( 0 )
-            , playcount( 0 )
             , track( t )
         {
             EngineController *engine = The::engineController();
+            if( !engine )
+                return; // engine might not be available during tests, silence the warning
 
             // force a direct connection or slot might not be called because of thread
             // affinity. (see BUG 300334)
-            connect( engine, SIGNAL(currentMetadataChanged( QVariantMap) ),
-                     this, SLOT(currentMetadataChanged( QVariantMap )),
+            connect( engine, &EngineController::currentMetadataChanged,
+                     this, &Private::currentMetadataChanged,
                      Qt::DirectConnection );
         }
 
     public Q_SLOTS:
-        void currentMetadataChanged( QVariantMap metaData )
+        void currentMetadataChanged( const QVariantMap &metaData )
         {
-            if( metaData.value( Meta::Field::URL ).toUrl() == url )
+            const QUrl metaDataUrl = metaData.value( Meta::Field::URL ).toUrl();
+            if( metaDataUrl == url )
             {
                 // keep synchronized to EngineController::slotMetaDataChanged()
                 if( metaData.contains( Meta::Field::ARTIST ) )
@@ -75,9 +75,9 @@ class MetaStream::Track::Private : public QObject
                 //TODO: move special handling to subclass or using some configurable XSPF
                 // Special demangling of artist/title for Shoutcast streams, which usually
                 // have "Artist - Title" in the title tag:
-                if( artist.isEmpty() && title.contains( " - " ) )
+                if( artist.isEmpty() && title.contains( QLatin1String(" - ") ) )
                 {
-                    const QStringList artist_title = title.split( " - " );
+                    const QStringList artist_title = title.split( QStringLiteral(" - ") );
                     if( artist_title.size() >= 2 )
                     {
                         artist = artist_title[0];
@@ -90,7 +90,7 @@ class MetaStream::Track::Private : public QObject
         }
 
     public:
-        KUrl url;
+        QUrl url;
         QString title;
         QString artist;
         QString album;
@@ -99,13 +99,6 @@ class MetaStream::Track::Private : public QObject
         QString comment;
         qint64 length;
 
-        // following are useful only sligtly, they are reset as soon as Amarok restarts
-        int rating;
-        double score;
-        QDateTime firstPlayed;
-        QDateTime lastPlayed;
-        int playcount;
-
         Meta::ArtistPtr artistPtr;
         Meta::AlbumPtr albumPtr;
         Meta::GenrePtr genrePtr;
@@ -122,12 +115,12 @@ class MetaStream::Track::Private : public QObject
 class StreamArtist : public Meta::DefaultArtist
 {
     public:
-        StreamArtist( MetaStream::Track::Private *dptr )
+        explicit StreamArtist( MetaStream::Track::Private *dptr )
             : DefaultArtist()
             , d( dptr )
             {}
 
-        QString name() const
+        QString name() const override
         {
             if( d && !d->artist.isEmpty() )
                 return d->artist;
@@ -140,29 +133,29 @@ class StreamArtist : public Meta::DefaultArtist
 class StreamAlbum : public Meta::DefaultAlbum
 {
 public:
-    StreamAlbum( MetaStream::Track::Private *dptr )
+    explicit StreamAlbum( MetaStream::Track::Private *dptr )
         : DefaultAlbum()
         , d( dptr )
     {}
 
-    ~StreamAlbum()
+    ~StreamAlbum() override
     {
         CoverCache::invalidateAlbum( this );
     }
 
-    bool hasAlbumArtist() const
+    bool hasAlbumArtist() const override
     {
         return false;
     }
 
-    QString name() const
+    QString name() const override
     {
         if( d && !d->album.isEmpty() )
             return d->album;
         return DefaultAlbum::name();
     }
 
-    bool hasImage( int size ) const
+    bool hasImage( int size ) const override
     {
         if( m_cover.isNull() )
             return Meta::Album::hasImage( size );
@@ -170,7 +163,7 @@ public:
             return true;
     }
 
-    QImage image( int size ) const
+    QImage image( int size ) const override
     {
         if( m_cover.isNull() )
             return Meta::Album::image( size );
@@ -178,7 +171,7 @@ public:
             return m_cover.scaled( size, size, Qt::KeepAspectRatio, Qt::SmoothTransformation );
     }
 
-    void setImage( const QImage &image )
+    void setImage( const QImage &image ) override
     {
         m_cover = image;
         CoverCache::invalidateAlbum( this );
@@ -191,12 +184,12 @@ public:
 class StreamGenre : public Meta::DefaultGenre
 {
 public:
-    StreamGenre( MetaStream::Track::Private *dptr )
+    explicit StreamGenre( MetaStream::Track::Private *dptr )
         : DefaultGenre()
         , d( dptr )
     {}
 
-    QString name() const
+    QString name() const override
     {
         if( d && !d->genre.isEmpty() )
             return d->genre;
