@@ -138,15 +138,15 @@ MusicDNSAudioDecoder::run(ThreadWeaver::JobPointer self, ThreadWeaver::Thread *t
     av_register_all();
 #endif
 
-    foreach( Meta::TrackPtr track, m_tracks )
+    for( Meta::TrackPtr track : m_tracks )
     {
         decode( track->playableUrl().toLocalFile(), &data, m_sampleLength );
         if( data.duration() > MIN_SAMPLE_LENGTH )
         {
-            QString fingerprint( ofa_create_print( ( unsigned char * ) data.data(),
+            QString fingerprint( QLatin1String( ofa_create_print( ( unsigned char * ) data.data(),
                                                    OFA_LITTLE_ENDIAN, ( data.length() >> 1 ),
-                                                   data.sRate(), data.channels() ) );
-            emit trackDecoded( track, fingerprint );
+                                                   data.sRate(), data.channels() ) ) );
+            Q_EMIT trackDecoded( track, fingerprint );
         }
         else
             warning() << QLatin1String( "Some error occurred during fingerprint generation, probably track is too short: " ) +
@@ -193,7 +193,7 @@ MusicDNSAudioDecoder::decode( const QString &fileName, DecodedAudioData *data, c
     bool isOk = true;
     av_log_set_level(AV_LOG_VERBOSE);
 
-    if( avformat_open_input( &pFormatCtx, fileName.toLocal8Bit(), nullptr, nullptr ) < 0 )
+    if( avformat_open_input( &pFormatCtx, fileName.toLocal8Bit().constData(), nullptr, nullptr ) < 0 )
     {
         warning() << QLatin1String( "Unable to open input file: " ) + fileName;
         return 0;
