@@ -84,7 +84,7 @@ Playlist::PlaylistLayoutEditDialog::PlaylistLayoutEditDialog( QWidget *parent )
     elementTabs->addTab( m_partsEdit[PlaylistLayout::Single], i18n( "Single" ) );
 
     QStringList layoutNames = LayoutManager::instance()->layouts();
-    foreach( const QString &layoutName, layoutNames )
+    for( const QString &layoutName : layoutNames )
     {
         PlaylistLayout layout = LayoutManager::instance()->layout( layoutName );
         layout.setDirty( false );
@@ -383,7 +383,7 @@ Playlist::PlaylistLayoutEditDialog::toggleUpDownButtons()
 void
 Playlist::PlaylistLayoutEditDialog::apply()  //SLOT
 {
-    foreach( const QString &layoutName, m_layoutsMap->keys() )
+    for( const QString &layoutName : m_layoutsMap->keys() )
     {
         PlaylistLayout layout = m_layoutsMap->value( layoutName );
 
@@ -500,7 +500,7 @@ Playlist::PlaylistLayoutEditDialog::setEnabledTabs()
 void
 Playlist::PlaylistLayoutEditDialog::setupGroupByCombo()
 {
-    foreach( const Playlist::Column &col, Playlist::groupableCategories() )
+    for( const Playlist::Column &col : Playlist::groupableCategories() )
     {
         groupByComboBox->addItem( QIcon::fromTheme( iconName( col ) ),
                                   columnName( col ),
