@@ -26,15 +26,14 @@
 #include <QObject>
 #include <QString>
 #include <QStringList>
-#include <QWeakPointer>
+#include <QPointer>
 
 namespace Collections
 {
     class Collection;
     class QueryMaker;
 }
-class QScriptEngine;
-class QScriptValue;
+class QJSEngine;
 
 namespace AmarokScript
 {
@@ -112,7 +111,7 @@ namespace AmarokScript
         Q_PROPERTY( QString prettyLocation READ prettyLocation )
 
         /**
-         * Returns a list of machine usable string*s representingthe collection location.
+         * Returns a list of machine usable string*s representing the collection location.
          * For example, a local collection would return a list of paths where tracks are
          * stored, while an Ampache collection would return a list with one string
          * containing the URL of an ampache server. Empty for collections like iPod collection and
@@ -121,7 +120,7 @@ namespace AmarokScript
         Q_PROPERTY( QStringList actualLocation READ actualLocation )
 
         public:
-            static void init( QScriptEngine *engine );
+            static void init( QJSEngine *engine );
             CollectionPrototype( Collections::Collection *collection );
             Collections::Collection* data() const { return m_collection.data(); }
 
@@ -133,13 +132,16 @@ namespace AmarokScript
             /**
              * Copy a single track to the destination collection
              */
-            Q_INVOKABLE void copyTracks( const Meta::TrackPtr track, Collections::Collection *targetCollection );
+            Q_INVOKABLE void copyTracks( const Meta::TrackPtr &track, Collections::Collection *targetCollection );
 
             /**
              * Convenience method for copying tracks based on QueryMaker results,
-             * takes ownership of the @param qm (The querymaker is rendered invalid
+             * takes ownership of the @p queryMaker. (The querymaker is rendered invalid
              * after copying).
              * @see copyTracks( Meta::TrackList, CollectionLocation* )
+             *
+             * @param queryMaker the Query maker.
+             * @param targetCollection the target collection.
              */
             Q_INVOKABLE void queryAndCopyTracks( Collections::QueryMaker *queryMaker, Collections::Collection *targetCollection );
 
@@ -151,13 +153,16 @@ namespace AmarokScript
             /**
              * Move a single track to the destination collection.
              */
-            Q_INVOKABLE void moveTracks( const Meta::TrackPtr track, Collections::Collection *targetCollection );
+            Q_INVOKABLE void moveTracks( const Meta::TrackPtr &track, Collections::Collection *targetCollection );
 
             /**
              * Convenience method for moving tracks based on QueryMaker results,
-             * takes ownership of the @param qm (The querymaker is rendered invalid
+             * takes ownership of the @p queryMaker (The querymaker is rendered invalid
              * after moving).
              * @see moveTracks( Meta::TrackList, CollectionLocation* )
+             *
+             * @param queryMaker the Query maker.
+             * @param targetCollection the target collection.
              */
             Q_INVOKABLE void queryAndMoveTracks( Collections::QueryMaker *queryMaker, Collections::Collection *targetCollection );
 
@@ -169,7 +174,7 @@ namespace AmarokScript
             /**
              * Remove single track from collection.
              */
-            Q_INVOKABLE void removeTracks( const Meta::TrackPtr track );
+            Q_INVOKABLE void removeTracks( const Meta::TrackPtr &track );
 
             /**
              * Convenience method for removing tracks selected by QueryMaker,
@@ -185,7 +190,7 @@ namespace AmarokScript
             Q_INVOKABLE Collections::QueryMaker *queryMaker();
 
         private:
-            QWeakPointer<Collections::Collection> m_collection;
+            QPointer<Collections::Collection> m_collection;
 
             bool isOrganizable() const;
             bool isWritable() const;
@@ -203,7 +208,7 @@ namespace AmarokScript
 
             Meta::TrackList removeInvalidTracks( const Meta::TrackList &tracks );
 
-       signals:
+       Q_SIGNALS:
            /**
             * This signal will be emitted after major changes to the collection
             * e.g. new songs where added, or an album changed
